---
name: "jose-jwk-thp"
section: "1"
platform: "linux"
package: "jose"
version: "15-2"
release: "Arch Linux 2026-11-01"
platforms: ["linux"]
url: "https://new.carta.tech/jose-jwk-thp"
---

# jose-jwk-thp(1)

Calculates the JWK thumbprint

## NAME

jose-jwk-thp - Calculates the JWK thumbprint

## SYNOPSIS

**jose jwk thp** -i JWK \[-H ALG\] \[-o THP\]

## OVERVIEW

The **jose jwk thp** command calculates the thumbprint of one or more JWKs.

## OPTIONS

• **-i** *JSON*, **--input**=*JSON* : Parse JWK(Set) from JSON

• **-i** *FILE*, **--input**=*FILE* : Read JWK(Set) from FILE

• **-i** -, **--input**=- : Read JWK(Set) standard input

• **-a** *ALG*, **--algorithm**=*ALG* : Use the specified hash algorithm (case sensitive)

• **-a** ?, **--algorithm**=? : List available hash algorithms

• **-o** *FILE*, **--output**=*FILE* : Write thumbprint(s) to FILE

• **-o** -, **--output**=- : Write thumbprint(s) to standard input

• **-f** *THP*, **--find**=*THP* : Search input keys for JWK with the given thumbprint

## EXAMPLES

Calculate the S1 thumbprint of a newly generated key:

```
$ jose jwk gen -i '{"alg":"ES256"}' -a S1 | jose jwk thp -i-
BzmSH6W8a8LlbQ1mD0iBJdYj4x4
```

Calculate the S256 thumbprints of a JWKSet containing two keys:

```
$ jose jwk thp -i keys.jwkset -a S256
6HJwXEuRh8gAkTz4BodEvcEj_KXkgjc-7Qez3d4VNMs
jo_j_O5gqYpKcZKHPp3miTszAeV60MXHvdb_kkjjTWE
```

Find the input key with the given thumbprint:

```
$ jose jwk thp -i keys.jwkset -f HYRNOxxOOHap0amTONoy1bHnS5M -o key.jwk
```

## AUTHOR

Nathaniel McCallum \<npmccallum@redhat.com\>

## SEE ALSO

[**jose-alg**(1)](/jose-alg/1.md), [**jose-jwk-gen**(1)](/jose-jwk-gen/1.md),
